# Script preparado para reproduzir as estimativas e 
# figuras do minicurso entitulado: Modelando dados amostrais complexos
# Ofertado no Encontro Mineiro de Estatística, UFMG, 2017 
# Author: Leo Bastos (PROCC/Fiocruz)
# Contato: leonardo.bastos @ fiocruz.br

# Nota: As figuras dependem dos pacotes arm e pyramid
# Duvidas com respeito a esse arquivo ou curso entre 
# em contato por email, lembrando de se identificar como 
# aluno do curso.

## ----eval=FALSE----------------------------------------------------------
## install.packages("nome_do_pacote")

## ----eval=FALSE----------------------------------------------------------
## # Instalando o pacote
##   install.packages("survey")

## ---- warning=FALSE, message=FALSE---------------------------------------
  # Chamando a biblioteca survey
  require(survey)

  # Lendo os microdados do Vigitel 2016 de BH
  BH <- read.csv("Data/VIGITEL_MicroDado_2016_BH.csv")
  
  # Tamanho da amostra
  nrow(BH)


## ---- warning=FALSE, message=FALSE---------------------------------------
  # Olhar o dicionário de variáveis!
  # Variável sexo - q7
  BH$sexo <- factor(x = BH$q7, levels = 1:2, 
               labels = c("Masculino", "Feminino"))

  table(BH$sexo)
  

## ------------------------------------------------------------------------
# Tabagismo por sexo (ignorando o desenho)
by(data = BH$fumante, INDICES = BH$sexo, FUN = function(x) 
      c(mean = mean(x), 
        sd = sqrt( mean(x) * (1-mean(x)) / length(x) )
       )  )

## ---- echo =FALSE, message=FALSE-----------------------------------------
# Faixa etaria
BH$fet = factor( BH$fet, labels = c("18 a 24", "25 a 34",
                                   "35 a 44", "45 a 54", 
                                   "55 a 64", "65 +"))

# Escolaridade
BH$fesc = factor( BH$fesc, labels = c("0 a 8 anos", 
                                      "9 a 11 anos",
                                      "12 anos e mais"))

# Atividade fisica
BH$af150 <- factor(BH$af3dominios, labels = c("AF < 150", "AF >= 150"))

# Alimentacao saudavel
BH$alimsau <- factor( BH$flvreg, labels = c("AS Nao", "AS Sim"))

# Comportamente Saudavel
BH$compsaude <- factor( BH$af3dominios + 2*BH$flvreg, labels = c("Nenhum", "Ativ. Fis.", "Alim. Sau.", "Ambos"))

aux <- table(BH$fet, BH$sexo)
pyramid::pyramid(data.frame(M = aux[,1], F = aux[,2], Ages = rownames(aux)), Llab = "Homens", Rlab = "Mulheres")

## ------------------------------------------------------------------------
# Definindo o desenho
BH.svy <- svydesign( id=~1, strata =NULL, fpc=NULL, 
                     weights = ~pesorake, data=BH)
# id -- variavel que define os clusters
#      ~1 significa que que não tem clusters
# strata -- variável que define os estratos
# fpc -- correção de população finita, aponta para a
#       variável do banco com o tamanho da população
# weights -- pesos amostrais
# data -- data frame com os dados gerados

## ------------------------------------------------------------------------
# Estimando o total de fumantes de BH em 2016
svytotal(~fumante, BH.svy)

# Estimando prevalência de tabagismo na capital
svymean(~fumante, BH.svy)

## ------------------------------------------------------------------------
# Tabagismo por sexo
svyby(formula = ~fumante, by = ~sexo, design = BH.svy, 
      FUN = svymean)

# Tabagismo por escolaridade
svyby(formula = ~fumante, by = ~fesc, design = BH.svy, 
      FUN = svymean)

## ---- echo = F-----------------------------------------------------------
# Tabagismo por faixa etaria
aux <- svyby(formula = ~fumante, by = ~fet, design = BH.svy, 
      FUN = svymean)
aux[,-1]

## ---- echo = F-----------------------------------------------------------
P1 <- svyby(formula = ~fumante, by = ~compsaude, design = BH.svy, FUN = svymean)

arm::coefplot(P1[,2], P1[,3], varnames=as.character(P1[,1]), main = "Prevalencias")

## ------------------------------------------------------------------------
# Modelo
modelo <- fumante ~ compsaude

# Ajuste
output <- svyglm(formula = modelo, 
                 family = binomial, 
                 design = BH.svy)


## ------------------------------------------------------------------------
summary(output)

## ---- echo=F-------------------------------------------------------------
output.aux <- output
class(output.aux) <- "glm"
arm::coefplot(output.aux, varnames=levels(BH$compsaude))


## ---- echo=F-------------------------------------------------------------
output3 <- glm(modelo, data = BH, family = binomial)

arm::coefplot(output.aux, varnames=levels(BH$compsaude))
arm::coefplot(output3, col=2, add=T)
legend("topright", c("glm", "svyglm"), col=2:1, lty=1, pch=20)


## ---- echo=F-------------------------------------------------------------
arm::coefplot(P1[,2], P1[,3], varnames=as.character(P1[,1]), main = "Prevalencias")

## ---- echo=F-------------------------------------------------------------
P2 <- predict( output, newdata = data.frame( compsaude = levels(BH$compsaude) ), type = "response" ,se.fit = T )
P2 <- data.frame(P2)

arm::coefplot(P1[,2], P1[,3], varnames=as.character(P1[,1]), main = "Prevalencias")
arm::coefplot(P2[,1], P2[,2], add = T, col=2)
legend("topright", c("svyglm", "svymean"), col=2:1, lty=1, pch=20)


## ---- warning=FALSE------------------------------------------------------
# Modelo
modelo2 <- fumante ~ compsaude + sexo + fet + fesc

# Ajuste
output2 <- svyglm(formula = modelo2, 
                 family = binomial, 
                 design = BH.svy)


## ---- echo=F-------------------------------------------------------------

class(output2) <- "glm"
arm::coefplot(output.aux, varnames = levels(BH$compsaude))
arm::coefplot(output2, col=2, add=T)
legend("topright", c("svyglm + covariaveis", "svyglm"), col=2:1, lty=1, pch=20)


